@@ -7,7 +7,7 @@ RDF::Query::Algebra::Triple - Algebra class for Triple patterns
 
 =head1 VERSION
 
-This document describes RDF::Query::Algebra::Triple version 2.914.
+This document describes RDF::Query::Algebra::Triple version 2.915.
 
 =cut
 
@@ -32,7 +32,7 @@ our ($VERSION);
 my %TRIPLE_LABELS;
 my @node_methods	= qw(subject predicate object);
 BEGIN {
-	$VERSION	= '2.914';
+	$VERSION	= '2.915';
 }
 
 ######################################################################
@@ -60,7 +60,11 @@ sub new {
 			$nodes[ $i ]	= RDF::Query::Node::Variable->new($node_methods[ $i ]);
 		}
 		if (blessed($nodes[ $i ]) and not($nodes[ $i ]->isa('RDF::Query::Node'))) {
-			$nodes[ $i ]	= RDF::Query::Node->from_trine( $nodes[ $i ] );
+			if ($nodes[ $i ]->isa('RDF::Trine::Node')) {
+				$nodes[ $i ]	= RDF::Query::Node->from_trine( $nodes[ $i ] );
+			} elsif ($nodes[ $i ]->does('Attean::API::TermOrVariable')){
+				$nodes[ $i ]	= RDF::Query::Node->from_attean( $nodes[ $i ] );
+			}
 		}
 	}
 	return $class->_new( @nodes );
