@@ -7,7 +7,7 @@ RDF::Query::Node - Base class for RDF Nodes
 
 =head1 VERSION
 
-This document describes RDF::Query::Node version 2.914.
+This document describes RDF::Query::Node version 2.915.
 
 =head1 METHODS
 
@@ -29,7 +29,7 @@ use RDF::Query::Node::Variable;
 
 our ($VERSION, @ISA, @EXPORT_OK, %EXPORT_TAGS);
 BEGIN {
-	$VERSION	= '2.914';
+	$VERSION	= '2.915';
 	
 	require Exporter;
 	@ISA		= qw(Exporter);
@@ -97,6 +97,29 @@ sub from_trine {
 	}
 }
 
+=item C<< from_attean ( $node ) >>
+
+Likewise, but from L<Attean>.
+
+=cut
+
+sub from_attean {
+	my $class	= shift;
+	my $n		= shift;
+	if ($n->does('Attean::API::Variable')) {
+		return RDF::Query::Node::Variable->new( $n->value );
+	} elsif ($n->does('Attean::API::Literal')) {
+		return RDF::Query::Node::Literal->new( $n->value, $n->language, $n->datatype );
+	} elsif ($n->does('Attean::API::IRI')) {
+		return RDF::Query::Node::Resource->new( $n->as_string );
+	} elsif ($n->does('Attean::API::Blank')) {
+		return RDF::Query::Node::Blank->new( $n->value );
+	} else {
+		use Data::Dumper;
+		Carp::confess "from_attean called with unrecognized node type:" . Dumper($n);
+	}
+}
+
 =item C<< explain >>
 
 Returns a string serialization of the node appropriate for display on the
